@@ -12,11 +12,6 @@ The I/O specifications corresponding to these base
 interfaces are found in the ``specs`` module.
 
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-
-from builtins import object, open, str, bytes
-
 from copy import deepcopy
 from datetime import datetime as dt
 import os
@@ -26,36 +21,38 @@ import shlex
 import sys
 import simplejson as json
 from dateutil.parser import parse as parseutc
-from future import standard_library
 from traits.trait_errors import TraitError
 
 from ... import config, logging, LooseVersion
 from ...utils.provenance import write_provenance
 from ...utils.misc import str2bool, rgetcwd
-from ...utils.filemanip import (FileNotFoundError, split_filename,
-                                which, get_dependencies)
+from ...utils.filemanip import split_filename, which, get_dependencies
 from ...utils.subprocess import run_command
 
 from ...external.due import due
 
 from .traits_extension import traits, isdefined
-from .specs import (BaseInterfaceInputSpec, CommandLineInputSpec,
-                    StdOutCommandLineInputSpec, MpiCommandLineInputSpec,
-                    get_filecopy_info)
-from .support import (Bunch, InterfaceResult, NipypeInterfaceError,
-                      format_help)
+from .specs import (
+    BaseInterfaceInputSpec,
+    CommandLineInputSpec,
+    StdOutCommandLineInputSpec,
+    MpiCommandLineInputSpec,
+    get_filecopy_info,
+)
+from .support import Bunch, InterfaceResult, NipypeInterfaceError, format_help
 
-standard_library.install_aliases()
+iflogger = logging.getLogger("nipype.interface")
 
-iflogger = logging.getLogger('nipype.interface')
-
-PY35 = sys.version_info >= (3, 5)
-PY3 = sys.version_info[0] > 2
 VALID_TERMINAL_OUTPUT = [
-    'stream', 'allatonce', 'file', 'file_split', 'file_stdout', 'file_stderr',
-    'none'
+    "stream",
+    "allatonce",
+    "file",
+    "file_split",
+    "file_stdout",
+    "file_stderr",
+    "none",
 ]
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
 
 class Interface(object):
@@ -124,8 +121,9 @@ class Interface(object):
         Necessary for pipeline operation
         """
         iflogger.warning(
-            '_get_filecopy_info member of Interface was deprecated '
-            'in nipype-1.1.6 and will be removed in 1.2.0')
+            "_get_filecopy_info member of Interface was deprecated "
+            "in nipype-1.1.6 and will be removed in 1.2.0"
+        )
         return get_filecopy_info(cls)
 
 
@@ -160,18 +158,26 @@ class BaseInterface(Interface):
 
 
     """
+
     input_spec = BaseInterfaceInputSpec
     _version = None
     _additional_metadata = []
     _redirect_x = False
     references_ = []
     resource_monitor = True  # Enabled for this interface IFF enabled in the config
+    _etelemetry_version_data = None
+
+    def __init__(
+        self, from_file=None, resource_monitor=None, ignore_exception=False, **inputs
+    ):
+        if config.getboolean("execution", "check_version"):
+            from ... import check_latest_version
+
+            if BaseInterface._etelemetry_version_data is None:
+                BaseInterface._etelemetry_version_data = check_latest_version()
 
-    def __init__(self, from_file=None, resource_monitor=None,
-                 ignore_exception=False, **inputs):
         if not self.input_spec:
-            raise Exception(
-                'No input_spec in class: %s' % self.__class__.__name__)
+            raise Exception("No input_spec in class: %s" % self.__class__.__name__)
 
         self.inputs = self.input_spec(**inputs)
         self.ignore_exception = ignore_exception
@@ -199,34 +205,42 @@ class BaseInterface(Interface):
         """
         if spec.requires:
             values = [
-                not isdefined(getattr(self.inputs, field))
-                for field in spec.requires
+                not isdefined(getattr(self.inputs, field)) for field in spec.requires
             ]
             if any(values) and isdefined(value):
                 if len(values) > 1:
-                    fmt = ("%s requires values for inputs %s because '%s' is set. "
-                           "For a list of required inputs, see %s.help()")
+                    fmt = (
+                        "%s requires values for inputs %s because '%s' is set. "
+                        "For a list of required inputs, see %s.help()"
+                    )
                 else:
-                    fmt = ("%s requires a value for input %s because '%s' is set. "
-                           "For a list of required inputs, see %s.help()")
-                msg = fmt % (self.__class__.__name__,
-                             ', '.join("'%s'" % req for req in spec.requires),
-                             name,
-                             self.__class__.__name__)
+                    fmt = (
+                        "%s requires a value for input %s because '%s' is set. "
+                        "For a list of required inputs, see %s.help()"
+                    )
+                msg = fmt % (
+                    self.__class__.__name__,
+                    ", ".join("'%s'" % req for req in spec.requires),
+                    name,
+                    self.__class__.__name__,
+                )
                 raise ValueError(msg)
 
     def _check_xor(self, spec, name, value):
         """ check if mutually exclusive inputs are satisfied
         """
         if spec.xor:
-            values = [
-                isdefined(getattr(self.inputs, field)) for field in spec.xor
-            ]
+            values = [isdefined(getattr(self.inputs, field)) for field in spec.xor]
             if not any(values) and not isdefined(value):
-                msg = ("%s requires a value for one of the inputs '%s'. "
-                       "For a list of required inputs, see %s.help()" %
-                       (self.__class__.__name__, ', '.join(spec.xor),
-                        self.__class__.__name__))
+                msg = (
+                    "%s requires a value for one of the inputs '%s'. "
+                    "For a list of required inputs, see %s.help()"
+                    % (
+                        self.__class__.__name__,
+                        ", ".join(spec.xor),
+                        self.__class__.__name__,
+                    )
+                )
                 raise ValueError(msg)
 
     def _check_mandatory_inputs(self):
@@ -236,15 +250,17 @@ class BaseInterface(Interface):
             value = getattr(self.inputs, name)
             self._check_xor(spec, name, value)
             if not isdefined(value) and spec.xor is None:
-                msg = ("%s requires a value for input '%s'. "
-                       "For a list of required inputs, see %s.help()" %
-                       (self.__class__.__name__, name,
-                        self.__class__.__name__))
+                msg = (
+                    "%s requires a value for input '%s'. "
+                    "For a list of required inputs, see %s.help()"
+                    % (self.__class__.__name__, name, self.__class__.__name__)
+                )
                 raise ValueError(msg)
             if isdefined(value):
                 self._check_requires(spec, name, value)
         for name, spec in list(
-                self.inputs.traits(mandatory=None, transient=None).items()):
+            self.inputs.traits(mandatory=None, transient=None).items()
+        ):
             self._check_requires(spec, name, getattr(self.inputs, name))
 
     def _check_version_requirements(self, trait_object, raise_exception=True):
@@ -258,16 +274,16 @@ class BaseInterface(Interface):
         if names and self.version:
             version = LooseVersion(str(self.version))
             for name in names:
-                min_ver = LooseVersion(
-                    str(trait_object.traits()[name].min_ver))
+                min_ver = LooseVersion(str(trait_object.traits()[name].min_ver))
                 if min_ver > version:
                     unavailable_traits.append(name)
                     if not isdefined(getattr(trait_object, name)):
                         continue
                     if raise_exception:
                         raise Exception(
-                            'Trait %s (%s) (version %s < required %s)' %
-                            (name, self.__class__.__name__, version, min_ver))
+                            "Trait %s (%s) (version %s < required %s)"
+                            % (name, self.__class__.__name__, version, min_ver)
+                        )
 
         # check maximum version
         check = dict(max_ver=lambda t: t is not None)
@@ -275,16 +291,16 @@ class BaseInterface(Interface):
         if names and self.version:
             version = LooseVersion(str(self.version))
             for name in names:
-                max_ver = LooseVersion(
-                    str(trait_object.traits()[name].max_ver))
+                max_ver = LooseVersion(str(trait_object.traits()[name].max_ver))
                 if max_ver < version:
                     unavailable_traits.append(name)
                     if not isdefined(getattr(trait_object, name)):
                         continue
                     if raise_exception:
                         raise Exception(
-                            'Trait %s (%s) (version %s > required %s)' %
-                            (name, self.__class__.__name__, version, max_ver))
+                            "Trait %s (%s) (version %s > required %s)"
+                            % (name, self.__class__.__name__, version, max_ver)
+                        )
         return unavailable_traits
 
     def _run_interface(self, runtime):
@@ -296,7 +312,7 @@ class BaseInterface(Interface):
         """ Add the interface references to the duecredit citations
         """
         for r in self.references_:
-            r['path'] = self.__module__
+            r["path"] = self.__module__
             due.cite(**r)
 
     def run(self, cwd=None, ignore_exception=None, **inputs):
@@ -338,10 +354,11 @@ class BaseInterface(Interface):
 
         # initialize provenance tracking
         store_provenance = str2bool(
-            config.get('execution', 'write_provenance', 'false'))
+            config.get("execution", "write_provenance", "false")
+        )
         env = deepcopy(dict(os.environ))
         if self._redirect_x:
-            env['DISPLAY'] = config.get_display()
+            env["DISPLAY"] = config.get_display()
 
         runtime = Bunch(
             cwd=cwd,
@@ -353,17 +370,19 @@ class BaseInterface(Interface):
             endTime=None,
             platform=platform.platform(),
             hostname=platform.node(),
-            version=self.version)
+            version=self.version,
+        )
         runtime_attrs = set(runtime.dictcopy())
 
         mon_sp = None
         if enable_rm:
-            mon_freq = float(
-                config.get('execution', 'resource_monitor_frequency', 1))
+            mon_freq = float(config.get("execution", "resource_monitor_frequency", 1))
             proc_pid = os.getpid()
             iflogger.debug(
-                'Creating a ResourceMonitor on a %s interface, PID=%d.',
-                self.__class__.__name__, proc_pid)
+                "Creating a ResourceMonitor on a %s interface, PID=%d.",
+                self.__class__.__name__,
+                proc_pid,
+            )
             mon_sp = ResourceMonitor(proc_pid, freq=mon_freq)
             mon_sp.start()
 
@@ -378,38 +397,37 @@ class BaseInterface(Interface):
             outputs = self.aggregate_outputs(runtime)
         except Exception as e:
             import traceback
+
             # Retrieve the maximum info fast
             runtime.traceback = traceback.format_exc()
             # Gather up the exception arguments and append nipype info.
-            exc_args = e.args if getattr(e, 'args') else tuple()
+            exc_args = e.args if getattr(e, "args") else tuple()
             exc_args += (
-                'An exception of type %s occurred while running interface %s.'
-                % (type(e).__name__, self.__class__.__name__), )
-            if config.get('logging', 'interface_level',
-                          'info').lower() == 'debug':
-                exc_args += ('Inputs: %s' % str(self.inputs), )
+                "An exception of type %s occurred while running interface %s."
+                % (type(e).__name__, self.__class__.__name__),
+            )
+            if config.get("logging", "interface_level", "info").lower() == "debug":
+                exc_args += ("Inputs: %s" % str(self.inputs),)
 
-            runtime.traceback_args = ('\n'.join(
-                ['%s' % arg for arg in exc_args]), )
+            runtime.traceback_args = ("\n".join(["%s" % arg for arg in exc_args]),)
 
             if not ignore_exception:
                 raise
         finally:
             if runtime is None or runtime_attrs - set(runtime.dictcopy()):
-                raise RuntimeError("{} interface failed to return valid "
-                                   "runtime object".format(
-                                       interface.__class__.__name__))
+                raise RuntimeError(
+                    "{} interface failed to return valid "
+                    "runtime object".format(interface.__class__.__name__)
+                )
             # This needs to be done always
             runtime.endTime = dt.isoformat(dt.utcnow())
             timediff = parseutc(runtime.endTime) - parseutc(runtime.startTime)
-            runtime.duration = (timediff.days * 86400 + timediff.seconds +
-                                timediff.microseconds / 1e6)
+            runtime.duration = (
+                timediff.days * 86400 + timediff.seconds + timediff.microseconds / 1e6
+            )
             results = InterfaceResult(
-                interface,
-                runtime,
-                inputs=inputs,
-                outputs=outputs,
-                provenance=None)
+                interface, runtime, inputs=inputs, outputs=outputs, provenance=None
+            )
 
             # Add provenance (if required)
             if store_provenance:
@@ -419,23 +437,24 @@ class BaseInterface(Interface):
             # Make sure runtime profiler is shut down
             if enable_rm:
                 import numpy as np
+
                 mon_sp.stop()
 
                 runtime.mem_peak_gb = None
                 runtime.cpu_percent = None
 
                 # Read .prof file in and set runtime values
-                vals = np.loadtxt(mon_sp.fname, delimiter=',')
+                vals = np.loadtxt(mon_sp.fname, delimiter=",")
                 if vals.size:
                     vals = np.atleast_2d(vals)
                     runtime.mem_peak_gb = vals[:, 2].max() / 1024
                     runtime.cpu_percent = vals[:, 1].max()
 
                     runtime.prof_dict = {
-                        'time': vals[:, 0].tolist(),
-                        'cpus': vals[:, 1].tolist(),
-                        'rss_GiB': (vals[:, 2] / 1024).tolist(),
-                        'vms_GiB': (vals[:, 3] / 1024).tolist(),
+                        "time": vals[:, 0].tolist(),
+                        "cpus": vals[:, 1].tolist(),
+                        "rss_GiB": (vals[:, 2] / 1024).tolist(),
+                        "vms_GiB": (vals[:, 3] / 1024).tolist(),
                     }
             os.chdir(syscwd)
 
@@ -466,18 +485,23 @@ class BaseInterface(Interface):
             na_names = aggregate_names.intersection(_na_outputs)
             if na_names:
                 # XXX Change to TypeError in Nipype 2.0
-                raise KeyError("""\
+                raise KeyError(
+                    """\
 Output trait(s) %s not available in version %s of interface %s.\
-""" % (', '.join(na_names), self.version, self.__class__.__name__))
+"""
+                    % (", ".join(na_names), self.version, self.__class__.__name__)
+                )
 
         for key in aggregate_names:  # Final aggregation
             val = predicted_outputs[key]
             try:
                 setattr(outputs, key, val)
             except TraitError as error:
-                if 'an existing' in getattr(error, 'info', 'default'):
-                    msg = "No such file or directory '%s' for output '%s' of a %s interface" % \
-                        (val, key, self.__class__.__name__)
+                if "an existing" in getattr(error, "info", "default"):
+                    msg = (
+                        "No such file or directory '%s' for output '%s' of a %s interface"
+                        % (val, key, self.__class__.__name__)
+                    )
                     raise FileNotFoundError(msg)
                 raise error
         return outputs
@@ -485,9 +509,10 @@ Output trait(s) %s not available in version %s of interface %s.\
     @property
     def version(self):
         if self._version is None:
-            if str2bool(config.get('execution', 'stop_on_unknown_version')):
-                raise ValueError('Interface %s has no version information' %
-                                 self.__class__.__name__)
+            if str2bool(config.get("execution", "stop_on_unknown_version")):
+                raise ValueError(
+                    "Interface %s has no version information" % self.__class__.__name__
+                )
         return self._version
 
     def load_inputs_from_json(self, json_file, overwrite=True):
@@ -512,8 +537,8 @@ Output trait(s) %s not available in version %s of interface %s.\
         A convenient way to save current inputs to a JSON file.
         """
         inputs = self.inputs.get_traitsfree()
-        iflogger.debug('saving inputs %s', inputs)
-        with open(json_file, 'w' if PY3 else 'wb') as fhandle:
+        iflogger.debug("saving inputs %s", inputs)
+        with open(json_file, "w") as fhandle:
             json.dump(inputs, fhandle, indent=4, ensure_ascii=False)
 
     def _pre_run_hook(self, runtime):
@@ -581,7 +606,8 @@ class SimpleInterface(BaseInterface):
 
     def __init__(self, from_file=None, resource_monitor=None, **inputs):
         super(SimpleInterface, self).__init__(
-            from_file=from_file, resource_monitor=resource_monitor, **inputs)
+            from_file=from_file, resource_monitor=resource_monitor, **inputs
+        )
         self._results = {}
 
     def _list_outputs(self):
@@ -622,11 +648,12 @@ class CommandLine(BaseInterface):
     '11c37f97649cd61627f4afe5136af8c0'
 
     """
+
     input_spec = CommandLineInputSpec
-    _cmd_prefix = ''
+    _cmd_prefix = ""
     _cmd = None
     _version = None
-    _terminal_output = 'stream'
+    _terminal_output = "stream"
 
     @classmethod
     def set_default_terminal_output(cls, output_type):
@@ -641,18 +668,16 @@ class CommandLine(BaseInterface):
         if output_type in VALID_TERMINAL_OUTPUT:
             cls._terminal_output = output_type
         else:
-            raise AttributeError(
-                'Invalid terminal output_type: %s' % output_type)
+            raise AttributeError("Invalid terminal output_type: %s" % output_type)
 
     def __init__(self, command=None, terminal_output=None, **inputs):
         super(CommandLine, self).__init__(**inputs)
         self._environ = None
         # Set command. Input argument takes precedence
-        self._cmd = command or getattr(self, '_cmd', None)
+        self._cmd = command or getattr(self, "_cmd", None)
 
         # Store dependencies in runtime object
-        self._ldd = str2bool(
-            config.get('execution', 'get_linked_libs', 'true'))
+        self._ldd = str2bool(config.get("execution", "get_linked_libs", "true"))
 
         if self._cmd is None:
             raise Exception("Missing command")
@@ -665,8 +690,9 @@ class CommandLine(BaseInterface):
         """sets base command, immutable"""
         if not self._cmd:
             raise NotImplementedError(
-                'CommandLineInterface should wrap an executable, but '
-                'none has been set.')
+                "CommandLineInterface should wrap an executable, but "
+                "none has been set."
+            )
         return self._cmd
 
     @property
@@ -675,7 +701,7 @@ class CommandLine(BaseInterface):
         validates arguments and generates command line"""
         self._check_mandatory_inputs()
         allargs = [self._cmd_prefix + self.cmd] + self._parse_inputs()
-        return ' '.join(allargs)
+        return " ".join(allargs)
 
     @property
     def terminal_output(self):
@@ -686,23 +712,26 @@ class CommandLine(BaseInterface):
         if value not in VALID_TERMINAL_OUTPUT:
             raise RuntimeError(
                 'Setting invalid value "%s" for terminal_output. Valid values are '
-                '%s.' % (value,
-                         ', '.join(['"%s"' % v
-                                    for v in VALID_TERMINAL_OUTPUT])))
+                "%s." % (value, ", ".join(['"%s"' % v for v in VALID_TERMINAL_OUTPUT]))
+            )
         self._terminal_output = value
 
     def raise_exception(self, runtime):
         raise RuntimeError(
-            ('Command:\n{cmdline}\nStandard output:\n{stdout}\n'
-             'Standard error:\n{stderr}\nReturn code: {returncode}'
-             ).format(**runtime.dictcopy()))
+            (
+                "Command:\n{cmdline}\nStandard output:\n{stdout}\n"
+                "Standard error:\n{stderr}\nReturn code: {returncode}"
+            ).format(**runtime.dictcopy())
+        )
 
     def _get_environ(self):
-        return getattr(self.inputs, 'environ', {})
+        return getattr(self.inputs, "environ", {})
 
-    def version_from_command(self, flag='-v', cmd=None):
-        iflogger.warning('version_from_command member of CommandLine was '
-                         'Deprecated in nipype-1.0.0 and deleted in 1.1.0')
+    def version_from_command(self, flag="-v", cmd=None):
+        iflogger.warning(
+            "version_from_command member of CommandLine was "
+            "Deprecated in nipype-1.0.0 and deleted in 1.1.0"
+        )
         if cmd is None:
             cmd = self.cmd.split()[0]
 
@@ -711,7 +740,7 @@ class CommandLine(BaseInterface):
             out_environ = self._get_environ()
             env.update(out_environ)
             proc = sp.Popen(
-                ' '.join((cmd, flag)),
+                " ".join((cmd, flag)),
                 shell=True,
                 env=env,
                 stdout=sp.PIPE,
@@ -720,7 +749,7 @@ class CommandLine(BaseInterface):
             o, e = proc.communicate()
             return o
 
-    def _run_interface(self, runtime, correct_return_codes=(0, )):
+    def _run_interface(self, runtime, correct_return_codes=(0,)):
         """Execute command via subprocess
 
         Parameters
@@ -748,16 +777,18 @@ class CommandLine(BaseInterface):
         if cmd_path is None:
             raise IOError(
                 'No command "%s" found on host %s. Please check that the '
-                'corresponding package is installed.' % (executable_name,
-                                                         runtime.hostname))
+                "corresponding package is installed."
+                % (executable_name, runtime.hostname)
+            )
 
         runtime.command_path = cmd_path
-        runtime.dependencies = (get_dependencies(executable_name,
-                                                 runtime.environ)
-                                if self._ldd else '<skipped>')
+        runtime.dependencies = (
+            get_dependencies(executable_name, runtime.environ)
+            if self._ldd
+            else "<skipped>"
+        )
         runtime = run_command(runtime, output=self.terminal_output)
-        if runtime.returncode is None or \
-                runtime.returncode not in correct_return_codes:
+        if runtime.returncode is None or runtime.returncode not in correct_return_codes:
             self.raise_exception(runtime)
 
         return runtime
@@ -768,15 +799,15 @@ class CommandLine(BaseInterface):
         Formats a trait containing argstr metadata
         """
         argstr = trait_spec.argstr
-        iflogger.debug('%s_%s', name, value)
+        iflogger.debug("%s_%s", name, value)
         if trait_spec.is_trait_type(traits.Bool) and "%" not in argstr:
             # Boolean options have no format string. Just append options if True.
             return argstr if value else None
         # traits.Either turns into traits.TraitCompound and does not have any
         # inner_traits
-        elif trait_spec.is_trait_type(traits.List) \
-            or (trait_spec.is_trait_type(traits.TraitCompound) and
-                isinstance(value, list)):
+        elif trait_spec.is_trait_type(traits.List) or (
+            trait_spec.is_trait_type(traits.TraitCompound) and isinstance(value, list)
+        ):
             # This is a bit simple-minded at present, and should be
             # construed as the default. If more sophisticated behavior
             # is needed, it can be accomplished with metadata (e.g.
@@ -786,13 +817,13 @@ class CommandLine(BaseInterface):
             # Depending on whether we stick with traitlets, and whether or
             # not we beef up traitlets.List, we may want to put some
             # type-checking code here as well
-            sep = trait_spec.sep if trait_spec.sep is not None else ' '
+            sep = trait_spec.sep if trait_spec.sep is not None else " "
 
-            if argstr.endswith('...'):
+            if argstr.endswith("..."):
                 # repeatable option
                 # --id %d... will expand to
                 # --id 1 --id 2 --id 3 etc.,.
-                argstr = argstr.replace('...', '')
+                argstr = argstr.replace("...", "")
                 return sep.join([argstr % elt for elt in value])
             else:
                 return argstr % sep.join(str(elt) for elt in value)
@@ -812,13 +843,16 @@ class CommandLine(BaseInterface):
                 return retval
 
             # Do not generate filename when excluded by other inputs
-            if any(isdefined(getattr(self.inputs, field))
-                   for field in trait_spec.xor or ()):
+            if any(
+                isdefined(getattr(self.inputs, field)) for field in trait_spec.xor or ()
+            ):
                 return retval
 
             # Do not generate filename when required fields are missing
-            if not all(isdefined(getattr(self.inputs, field))
-                       for field in trait_spec.requires or ()):
+            if not all(
+                isdefined(getattr(self.inputs, field))
+                for field in trait_spec.requires or ()
+            ):
                 return retval
 
             if isdefined(retval) and "%s" in retval:
@@ -831,15 +865,14 @@ class CommandLine(BaseInterface):
             ns = trait_spec.name_source
             while isinstance(ns, (list, tuple)):
                 if len(ns) > 1:
-                    iflogger.warning(
-                        'Only one name_source per trait is allowed')
+                    iflogger.warning("Only one name_source per trait is allowed")
                 ns = ns[0]
 
             if not isinstance(ns, (str, bytes)):
                 raise ValueError(
-                    'name_source of \'{}\' trait should be an input trait '
-                    'name, but a type {} object was found'.format(
-                        name, type(ns)))
+                    "name_source of '{}' trait should be an input trait "
+                    "name, but a type {} object was found".format(name, type(ns))
+                )
 
             if isdefined(getattr(self.inputs, ns)):
                 name_source = ns
@@ -854,8 +887,7 @@ class CommandLine(BaseInterface):
                     base = source
             else:
                 if name in chain:
-                    raise NipypeInterfaceError(
-                        'Mutually pointing name_sources')
+                    raise NipypeInterfaceError("Mutually pointing name_sources")
 
                 chain.append(name)
                 base = self._filename_from_source(ns, chain)
@@ -943,7 +975,7 @@ class StdOutCommandLine(CommandLine):
     input_spec = StdOutCommandLineInputSpec
 
     def _gen_filename(self, name):
-        return self._gen_outfilename() if name == 'out_file' else None
+        return self._gen_outfilename() if name == "out_file" else None
 
     def _gen_outfilename(self):
         raise NotImplementedError
@@ -966,6 +998,7 @@ class MpiCommandLine(CommandLine):
     >>> mpi_cli.cmdline
     'mpiexec -n 8 my_mpi_prog -v'
     """
+
     input_spec = MpiCommandLineInputSpec
 
     @property
@@ -973,11 +1006,11 @@ class MpiCommandLine(CommandLine):
         """Adds 'mpiexec' to begining of command"""
         result = []
         if self.inputs.use_mpi:
-            result.append('mpiexec')
+            result.append("mpiexec")
             if self.inputs.n_procs:
-                result.append('-n %d' % self.inputs.n_procs)
+                result.append("-n %d" % self.inputs.n_procs)
         result.append(super(MpiCommandLine, self).cmdline)
-        return ' '.join(result)
+        return " ".join(result)
 
 
 class SEMLikeCommandLine(CommandLine):
@@ -997,10 +1030,8 @@ class SEMLikeCommandLine(CommandLine):
         for name in list(outputs.keys()):
             corresponding_input = getattr(self.inputs, name)
             if isdefined(corresponding_input):
-                if (isinstance(corresponding_input, bool)
-                        and corresponding_input):
-                    outputs[name] = \
-                        os.path.abspath(self._outputs_filenames[name])
+                if isinstance(corresponding_input, bool) and corresponding_input:
+                    outputs[name] = os.path.abspath(self._outputs_filenames[name])
                 else:
                     if isinstance(corresponding_input, list):
                         outputs[name] = [
@@ -1028,18 +1059,23 @@ class LibraryBaseInterface(BaseInterface):
         super(LibraryBaseInterface, self).__init__(*args, **kwargs)
         if check_import:
             import pkgutil
+
             failed_imports = []
             for pkg in (self._pkg,) + tuple(self.imports):
                 if pkgutil.find_loader(pkg) is None:
                     failed_imports.append(pkg)
             if failed_imports:
-                iflogger.warning('Unable to import %s; %s interface may fail to '
-                                 'run', failed_imports, self.__class__.__name__)
+                iflogger.warning(
+                    "Unable to import %s; %s interface may fail to " "run",
+                    failed_imports,
+                    self.__class__.__name__,
+                )
 
     @property
     def version(self):
         if self._version is None:
             import importlib
+
             try:
                 self._version = importlib.import_module(self._pkg).__version__
             except (ImportError, AttributeError):
@@ -1060,14 +1096,15 @@ class PackageInfo(object):
                     clout = CommandLine(
                         command=klass.version_cmd,
                         resource_monitor=False,
-                        terminal_output='allatonce').run()
+                        terminal_output="allatonce",
+                    ).run()
                 except IOError:
                     return None
 
                 raw_info = clout.runtime.stdout
             elif klass.version_file is not None:
                 try:
-                    with open(klass.version_file, 'rt') as fobj:
+                    with open(klass.version_file, "rt") as fobj:
                         raw_info = fobj.read()
                 except OSError:
                     return None
