@@ -2,70 +2,94 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """ General matlab interface code """
-from __future__ import print_function, division, unicode_literals, absolute_import
-from builtins import open
 import os
 
 from .. import config
-from .base import (CommandLineInputSpec, InputMultiPath, isdefined,
-                   CommandLine, traits, File, Directory)
+from .base import (
+    CommandLineInputSpec,
+    InputMultiPath,
+    isdefined,
+    CommandLine,
+    traits,
+    File,
+    Directory,
+)
 
 
 def get_matlab_command():
-    if 'NIPYPE_NO_MATLAB' in os.environ:
+    if "NIPYPE_NO_MATLAB" in os.environ:
         return None
 
     try:
-        matlab_cmd = os.environ['MATLABCMD']
+        matlab_cmd = os.environ["MATLABCMD"]
     except:
-        matlab_cmd = 'matlab'
+        matlab_cmd = "matlab"
 
     try:
-        res = CommandLine(command='which', args=matlab_cmd,
-                          resource_monitor=False,
-                          terminal_output='allatonce').run()
+        res = CommandLine(
+            command="which",
+            args=matlab_cmd,
+            resource_monitor=False,
+            terminal_output="allatonce",
+        ).run()
         matlab_path = res.runtime.stdout.strip()
-    except Exception as e:
+    except Exception:
         return None
     return matlab_cmd
 
+
 no_matlab = get_matlab_command() is None
 
 
 class MatlabInputSpec(CommandLineInputSpec):
     """ Basic expected inputs to Matlab interface """
 
-    script = traits.Str(argstr='-r \"%s;exit\"', desc='m-code to run',
-                        mandatory=True, position=-1)
-    uses_mcr = traits.Bool(desc='use MCR interface',
-                           xor=['nodesktop', 'nosplash',
-                                'single_comp_thread'],
-                           nohash=True)
-    nodesktop = traits.Bool(True, argstr='-nodesktop',
-                            usedefault=True,
-                            desc='Switch off desktop mode on unix platforms',
-                            nohash=True)
-    nosplash = traits.Bool(True, argstr='-nosplash', usedefault=True,
-                           desc='Switch of splash screen',
-                           nohash=True)
-    logfile = File(argstr='-logfile %s',
-                          desc='Save matlab output to log')
-    single_comp_thread = traits.Bool(argstr="-singleCompThread",
-                                     desc="force single threaded operation",
-                                     nohash=True)
+    script = traits.Str(
+        argstr='-r "%s;exit"', desc="m-code to run", mandatory=True, position=-1
+    )
+    uses_mcr = traits.Bool(
+        desc="use MCR interface",
+        xor=["nodesktop", "nosplash", "single_comp_thread"],
+        nohash=True,
+    )
+    nodesktop = traits.Bool(
+        True,
+        argstr="-nodesktop",
+        usedefault=True,
+        desc="Switch off desktop mode on unix platforms",
+        nohash=True,
+    )
+    nosplash = traits.Bool(
+        True,
+        argstr="-nosplash",
+        usedefault=True,
+        desc="Switch of splash screen",
+        nohash=True,
+    )
+    logfile = File(argstr="-logfile %s", desc="Save matlab output to log")
+    single_comp_thread = traits.Bool(
+        argstr="-singleCompThread", desc="force single threaded operation", nohash=True
+    )
     # non-commandline options
-    mfile = traits.Bool(True, desc='Run m-code using m-file',
-                        usedefault=True)
-    script_file = File('pyscript.m', usedefault=True,
-                       desc='Name of file to write m-code to')
-    paths = InputMultiPath(Directory(), desc='Paths to add to matlabpath')
-    prescript = traits.List(["ver,", "try,"], usedefault=True,
-                            desc='prescript to be added before code')
-    postscript = traits.List(["\n,catch ME,",
-                              "fprintf(2,'MATLAB code threw an exception:\\n');",
-                              "fprintf(2,'%s\\n',ME.message);",
-                              "if length(ME.stack) ~= 0, fprintf(2,'File:%s\\nName:%s\\nLine:%d\\n',ME.stack.file,ME.stack.name,ME.stack.line);, end;",
-                              "end;"], desc='script added after code', usedefault=True)
+    mfile = traits.Bool(True, desc="Run m-code using m-file", usedefault=True)
+    script_file = File(
+        "pyscript.m", usedefault=True, desc="Name of file to write m-code to"
+    )
+    paths = InputMultiPath(Directory(), desc="Paths to add to matlabpath")
+    prescript = traits.List(
+        ["ver,", "try,"], usedefault=True, desc="prescript to be added before code"
+    )
+    postscript = traits.List(
+        [
+            "\n,catch ME,",
+            "fprintf(2,'MATLAB code threw an exception:\\n');",
+            "fprintf(2,'%s\\n',ME.message);",
+            "if length(ME.stack) ~= 0, fprintf(2,'File:%s\\nName:%s\\nLine:%d\\n',ME.stack.file,ME.stack.name,ME.stack.line);, end;",
+            "end;",
+        ],
+        desc="script added after code",
+        usedefault=True,
+    )
 
 
 class MatlabCommand(CommandLine):
@@ -77,7 +101,7 @@ class MatlabCommand(CommandLine):
     >>> out = mlab.run()  # doctest: +SKIP
     """
 
-    _cmd = 'matlab'
+    _cmd = "matlab"
     _default_matlab_cmd = None
     _default_mfile = None
     _default_paths = None
@@ -99,13 +123,14 @@ class MatlabCommand(CommandLine):
         if self._default_paths and not isdefined(self.inputs.paths):
             self.inputs.paths = self._default_paths
 
-        if not isdefined(self.inputs.single_comp_thread) and \
-                not isdefined(self.inputs.uses_mcr):
-            if config.getboolean('execution', 'single_thread_matlab'):
+        if not isdefined(self.inputs.single_comp_thread) and not isdefined(
+            self.inputs.uses_mcr
+        ):
+            if config.getboolean("execution", "single_thread_matlab"):
                 self.inputs.single_comp_thread = True
         # For matlab commands force all output to be returned since matlab
         # does not have a clean way of notifying an error
-        self.terminal_output = 'allatonce'
+        self.terminal_output = "allatonce"
 
     @classmethod
     def set_default_matlab_cmd(cls, matlab_cmd):
@@ -141,23 +166,23 @@ class MatlabCommand(CommandLine):
         cls._default_paths = paths
 
     def _run_interface(self, runtime):
-        self.terminal_output = 'allatonce'
+        self.terminal_output = "allatonce"
         runtime = super(MatlabCommand, self)._run_interface(runtime)
         try:
             # Matlab can leave the terminal in a barbbled state
-            os.system('stty sane')
+            os.system("stty sane")
         except:
             # We might be on a system where stty doesn't exist
             pass
-        if 'MATLAB code threw an exception' in runtime.stderr:
+        if "MATLAB code threw an exception" in runtime.stderr:
             self.raise_exception(runtime)
         return runtime
 
     def _format_arg(self, name, trait_spec, value):
-        if name in ['script']:
+        if name in ["script"]:
             argstr = trait_spec.argstr
             if self.inputs.uses_mcr:
-                argstr = '%s'
+                argstr = "%s"
             return self._gen_matlab_command(argstr, value)
         return super(MatlabCommand, self)._format_arg(name, trait_spec, value)
 
@@ -174,7 +199,9 @@ class MatlabCommand(CommandLine):
 
         # prescript takes different default value depending on the mfile argument
         if mfile:
-            prescript.insert(0, "fprintf(1,'Executing %s at %s:\\n',mfilename(),datestr(now));")
+            prescript.insert(
+                0, "fprintf(1,'Executing %s at %s:\\n',mfilename(),datestr(now));"
+            )
         else:
             prescript.insert(0, "fprintf(1,'Executing code at %s:\\n',datestr(now));")
         for path in paths:
@@ -182,16 +209,25 @@ class MatlabCommand(CommandLine):
 
         if not mfile:
             # clean up the code of comments and replace newlines with commas
-            script_lines = ','.join([line for line in script_lines.split("\n") if not line.strip().startswith("%")])
+            script_lines = ",".join(
+                [
+                    line
+                    for line in script_lines.split("\n")
+                    if not line.strip().startswith("%")
+                ]
+            )
 
-        script_lines = '\n'.join(prescript) + script_lines + '\n'.join(postscript)
+        script_lines = "\n".join(prescript) + script_lines + "\n".join(postscript)
         if mfile:
-            with open(os.path.join(cwd, self.inputs.script_file), 'wt') as mfile:
+            with open(os.path.join(cwd, self.inputs.script_file), "wt") as mfile:
                 mfile.write(script_lines)
             if self.inputs.uses_mcr:
-                script = '%s' % (os.path.join(cwd, self.inputs.script_file))
+                script = "%s" % (os.path.join(cwd, self.inputs.script_file))
             else:
-                script = "addpath('%s');%s" % (cwd, self.inputs.script_file.split('.')[0])
+                script = "addpath('%s');%s" % (
+                    cwd,
+                    self.inputs.script_file.split(".")[0],
+                )
         else:
-            script = ''.join(script_lines.split('\n'))
+            script = "".join(script_lines.split("\n"))
         return argstr % script
