@@ -6,8 +6,6 @@
 Support for child processes running as non-daemons based on
 http://stackoverflow.com/a/8963618/1183453
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
 
 # Import packages
 import os
@@ -38,7 +36,7 @@ except ImportError:
 
 
 # Init logger
-logger = logging.getLogger('nipype.workflow')
+logger = logging.getLogger("nipype.workflow")
 
 
 # Run node
@@ -66,14 +64,15 @@ def run_node(node, updatehash, taskid):
 
     # Try and execute the node via node.run()
     try:
-        result['result'] = node.run(updatehash=updatehash)
+        result["result"] = node.run(updatehash=updatehash)
     except:  # noqa: E722, intendedly catch all here
-        result['traceback'] = format_exception(*sys.exc_info())
-        result['result'] = node.result
+        result["traceback"] = format_exception(*sys.exc_info())
+        result["result"] = node.result
 
     # Return the result dictionary
     return result
 
+
 # Pythons 2.7, 3.4-3.7.0, and 3.7.1 have three different implementations of
 # pool.Pool().Process(), and the type of the result varies based on the default
 # multiprocessing context, so we need to dynamically patch the daemon property
@@ -86,51 +85,70 @@ class NonDaemonMixin(object):
     def daemon(self, val):
         pass
 
+
 try:
     from multiprocessing import context
+
     # Exists on all platforms
     class NonDaemonSpawnProcess(NonDaemonMixin, context.SpawnProcess):
         pass
+
     class NonDaemonSpawnContext(context.SpawnContext):
         Process = NonDaemonSpawnProcess
-    _nondaemon_context_mapper = {
-        'spawn': NonDaemonSpawnContext()
-        }
+
+    _nondaemon_context_mapper = {"spawn": NonDaemonSpawnContext()}
 
     # POSIX only
     try:
+
         class NonDaemonForkProcess(NonDaemonMixin, context.ForkProcess):
             pass
+
         class NonDaemonForkContext(context.ForkContext):
             Process = NonDaemonForkProcess
-        _nondaemon_context_mapper['fork'] = NonDaemonForkContext()
+
+        _nondaemon_context_mapper["fork"] = NonDaemonForkContext()
     except AttributeError:
         pass
     # POSIX only
     try:
+
         class NonDaemonForkServerProcess(NonDaemonMixin, context.ForkServerProcess):
             pass
+
         class NonDaemonForkServerContext(context.ForkServerContext):
             Process = NonDaemonForkServerProcess
-        _nondaemon_context_mapper['forkserver'] = NonDaemonForkServerContext()
+
+        _nondaemon_context_mapper["forkserver"] = NonDaemonForkServerContext()
     except AttributeError:
         pass
 
     class NonDaemonPool(pool.Pool):
-        def __init__(self, processes=None, initializer=None, initargs=(),
-                     maxtasksperchild=None, context=None):
+        def __init__(
+            self,
+            processes=None,
+            initializer=None,
+            initargs=(),
+            maxtasksperchild=None,
+            context=None,
+        ):
             if context is None:
                 context = mp.get_context()
             context = _nondaemon_context_mapper[context._name]
-            super(NonDaemonPool, self).__init__(processes=processes,
-                                                initializer=initializer,
-                                                initargs=initargs,
-                                                maxtasksperchild=maxtasksperchild,
-                                                context=context)
+            super(NonDaemonPool, self).__init__(
+                processes=processes,
+                initializer=initializer,
+                initargs=initargs,
+                maxtasksperchild=maxtasksperchild,
+                context=context,
+            )
+
 
 except ImportError:
+
     class NonDaemonProcess(NonDaemonMixin, mp.Process):
         pass
+
     class NonDaemonPool(pool.Pool):
         Process = NonDaemonProcess
 
@@ -181,19 +199,24 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
         self._cwd = os.getcwd()
 
         # Read in options or set defaults.
-        non_daemon = self.plugin_args.get('non_daemon', True)
-        maxtasks = self.plugin_args.get('maxtasksperchild', 10)
-        self.processors = self.plugin_args.get('n_procs', cpu_count())
+        non_daemon = self.plugin_args.get("non_daemon", True)
+        maxtasks = self.plugin_args.get("maxtasksperchild", 10)
+        self.processors = self.plugin_args.get("n_procs", cpu_count())
         self.memory_gb = self.plugin_args.get(
-            'memory_gb',  # Allocate 90% of system memory
-            get_system_total_memory_gb() * 0.9)
-        self.raise_insufficient = self.plugin_args.get('raise_insufficient',
-                                                       True)
+            "memory_gb",  # Allocate 90% of system memory
+            get_system_total_memory_gb() * 0.9,
+        )
+        self.raise_insufficient = self.plugin_args.get("raise_insufficient", True)
 
         # Instantiate different thread pools for non-daemon processes
-        logger.debug('[LegacyMultiProc] Starting in "%sdaemon" mode (n_procs=%d, '
-                     'mem_gb=%0.2f, cwd=%s)', 'non' * int(non_daemon),
-                     self.processors, self.memory_gb, self._cwd)
+        logger.debug(
+            '[LegacyMultiProc] Starting in "%sdaemon" mode (n_procs=%d, '
+            "mem_gb=%0.2f, cwd=%s)",
+            "non" * int(non_daemon),
+            self.processors,
+            self.memory_gb,
+            self._cwd,
+        )
 
         NipypePool = NonDaemonPool if non_daemon else Pool
         try:
@@ -201,7 +224,7 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
                 processes=self.processors,
                 maxtasksperchild=maxtasks,
                 initializer=os.chdir,
-                initargs=(self._cwd,)
+                initargs=(self._cwd,),
             )
         except TypeError:
             # Python < 3.2 does not have maxtasksperchild
@@ -214,7 +237,7 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
     def _async_callback(self, args):
         # Make sure runtime is not left at a dubious working directory
         os.chdir(self._cwd)
-        self._taskresult[args['taskid']] = args
+        self._taskresult[args["taskid"]] = args
 
     def _get_result(self, taskid):
         return self._taskresult.get(taskid)
@@ -226,15 +249,18 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
         self._taskid += 1
 
         # Don't allow streaming outputs
-        if getattr(node.interface, 'terminal_output', '') == 'stream':
-            node.interface.terminal_output = 'allatonce'
+        if getattr(node.interface, "terminal_output", "") == "stream":
+            node.interface.terminal_output = "allatonce"
 
         self._task_obj[self._taskid] = self.pool.apply_async(
-            run_node, (node, updatehash, self._taskid),
-            callback=self._async_callback)
+            run_node, (node, updatehash, self._taskid), callback=self._async_callback
+        )
 
-        logger.debug('[LegacyMultiProc] Submitted task %s (taskid=%d).',
-                     node.fullname, self._taskid)
+        logger.debug(
+            "[LegacyMultiProc] Submitted task %s (taskid=%d).",
+            node.fullname,
+            self._taskid,
+        )
         return self._taskid
 
     def _prerun_check(self, graph):
@@ -247,17 +273,19 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
 
         if np.any(np.array(tasks_mem_gb) > self.memory_gb):
             logger.warning(
-                'Some nodes exceed the total amount of memory available '
-                '(%0.2fGB).', self.memory_gb)
+                "Some nodes exceed the total amount of memory available " "(%0.2fGB).",
+                self.memory_gb,
+            )
             if self.raise_insufficient:
-                raise RuntimeError('Insufficient resources available for job')
+                raise RuntimeError("Insufficient resources available for job")
 
         if np.any(np.array(tasks_num_th) > self.processors):
             logger.warning(
-                'Some nodes demand for more threads than available (%d).',
-                self.processors)
+                "Some nodes demand for more threads than available (%d).",
+                self.processors,
+            )
             if self.raise_insufficient:
-                raise RuntimeError('Insufficient resources available for job')
+                raise RuntimeError("Insufficient resources available for job")
 
     def _postrun_check(self):
         self.pool.close()
@@ -282,46 +310,58 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
         # Check to see if a job is available (jobs with all dependencies run)
         # See https://github.com/nipy/nipype/pull/2200#discussion_r141605722
         # See also https://github.com/nipy/nipype/issues/2372
-        jobids = np.flatnonzero(~self.proc_done &
-                                (self.depidx.sum(axis=0) == 0).__array__())
+        jobids = np.flatnonzero(
+            ~self.proc_done & (self.depidx.sum(axis=0) == 0).__array__()
+        )
 
         # Check available resources by summing all threads and memory used
-        free_memory_gb, free_processors = self._check_resources(
-            self.pending_tasks)
+        free_memory_gb, free_processors = self._check_resources(self.pending_tasks)
 
-        stats = (len(self.pending_tasks), len(jobids), free_memory_gb,
-                 self.memory_gb, free_processors, self.processors)
+        stats = (
+            len(self.pending_tasks),
+            len(jobids),
+            free_memory_gb,
+            self.memory_gb,
+            free_processors,
+            self.processors,
+        )
         if self._stats != stats:
-            tasks_list_msg = ''
+            tasks_list_msg = ""
 
             if logger.level <= INFO:
                 running_tasks = [
-                    '  * %s' % self.procs[jobid].fullname
+                    "  * %s" % self.procs[jobid].fullname
                     for _, jobid in self.pending_tasks
                 ]
                 if running_tasks:
-                    tasks_list_msg = '\nCurrently running:\n'
-                    tasks_list_msg += '\n'.join(running_tasks)
-                    tasks_list_msg = indent(tasks_list_msg, ' ' * 21)
+                    tasks_list_msg = "\nCurrently running:\n"
+                    tasks_list_msg += "\n".join(running_tasks)
+                    tasks_list_msg = indent(tasks_list_msg, " " * 21)
             logger.info(
-                '[LegacyMultiProc] Running %d tasks, and %d jobs ready. Free '
-                'memory (GB): %0.2f/%0.2f, Free processors: %d/%d.%s',
-                len(self.pending_tasks), len(jobids), free_memory_gb,
-                self.memory_gb, free_processors, self.processors,
-                tasks_list_msg)
+                "[LegacyMultiProc] Running %d tasks, and %d jobs ready. Free "
+                "memory (GB): %0.2f/%0.2f, Free processors: %d/%d.%s",
+                len(self.pending_tasks),
+                len(jobids),
+                free_memory_gb,
+                self.memory_gb,
+                free_processors,
+                self.processors,
+                tasks_list_msg,
+            )
             self._stats = stats
 
         if free_memory_gb < 0.01 or free_processors == 0:
-            logger.debug('No resources available')
+            logger.debug("No resources available")
             return
 
         if len(jobids) + len(self.pending_tasks) == 0:
-            logger.debug('No tasks are being run, and no jobs can '
-                         'be submitted to the queue. Potential deadlock')
+            logger.debug(
+                "No tasks are being run, and no jobs can "
+                "be submitted to the queue. Potential deadlock"
+            )
             return
 
-        jobids = self._sort_jobs(
-            jobids, scheduler=self.plugin_args.get('scheduler'))
+        jobids = self._sort_jobs(jobids, scheduler=self.plugin_args.get("scheduler"))
 
         # Run garbage collector before potentially submitting jobs
         gc.collect()
@@ -335,12 +375,8 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
                 except Exception:
                     traceback = format_exception(*sys.exc_info())
                     self._clean_queue(
-                        jobid,
-                        graph,
-                        result={
-                            'result': None,
-                            'traceback': traceback
-                        })
+                        jobid, graph, result={"result": None, "traceback": traceback}
+                    )
                     self.proc_pending[jobid] = False
                     continue
                 if num_subnodes > 1:
@@ -354,16 +390,26 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
 
             # If node does not fit, skip at this moment
             if next_job_th > free_processors or next_job_gb > free_memory_gb:
-                logger.debug('Cannot allocate job %d (%0.2fGB, %d threads).',
-                             jobid, next_job_gb, next_job_th)
+                logger.debug(
+                    "Cannot allocate job %d (%0.2fGB, %d threads).",
+                    jobid,
+                    next_job_gb,
+                    next_job_th,
+                )
                 continue
 
             free_memory_gb -= next_job_gb
             free_processors -= next_job_th
-            logger.debug('Allocating %s ID=%d (%0.2fGB, %d threads). Free: '
-                         '%0.2fGB, %d threads.', self.procs[jobid].fullname,
-                         jobid, next_job_gb, next_job_th, free_memory_gb,
-                         free_processors)
+            logger.debug(
+                "Allocating %s ID=%d (%0.2fGB, %d threads). Free: "
+                "%0.2fGB, %d threads.",
+                self.procs[jobid].fullname,
+                jobid,
+                next_job_gb,
+                next_job_th,
+                free_memory_gb,
+                free_processors,
+            )
 
             # change job status in appropriate queues
             self.proc_done[jobid] = True
@@ -375,19 +421,14 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
 
             # updatehash and run_without_submitting are also run locally
             if updatehash or self.procs[jobid].run_without_submitting:
-                logger.debug('Running node %s on master thread',
-                             self.procs[jobid])
+                logger.debug("Running node %s on master thread", self.procs[jobid])
                 try:
                     self.procs[jobid].run(updatehash=updatehash)
                 except Exception:
                     traceback = format_exception(*sys.exc_info())
                     self._clean_queue(
-                        jobid,
-                        graph,
-                        result={
-                            'result': None,
-                            'traceback': traceback
-                        })
+                        jobid, graph, result={"result": None, "traceback": traceback}
+                    )
 
                 # Release resources
                 self._task_finished_cb(jobid)
@@ -404,9 +445,8 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
             # Task should be submitted to workers
             # Send job to task manager and add to pending tasks
             if self._status_callback:
-                self._status_callback(self.procs[jobid], 'start')
-            tid = self._submit_job(
-                deepcopy(self.procs[jobid]), updatehash=updatehash)
+                self._status_callback(self.procs[jobid], "start")
+            tid = self._submit_job(deepcopy(self.procs[jobid]), updatehash=updatehash)
             if tid is None:
                 self.proc_done[jobid] = False
                 self.proc_pending[jobid] = False
@@ -415,10 +455,10 @@ class LegacyMultiProcPlugin(DistributedPluginBase):
             # Display stats next loop
             self._stats = None
 
-    def _sort_jobs(self, jobids, scheduler='tsort'):
-        if scheduler == 'mem_thread':
+    def _sort_jobs(self, jobids, scheduler="tsort"):
+        if scheduler == "mem_thread":
             return sorted(
                 jobids,
-                key=lambda item: (self.procs[item].mem_gb, self.procs[item].n_procs)
+                key=lambda item: (self.procs[item].mem_gb, self.procs[item].n_procs),
             )
         return jobids
